@@ -1,4 +1,3 @@
-context("plot.singleEventCB")
 # Uncomment next line to skip tests in non-interactive session
 skip_if_not_installed("glmnet")
 skip_if_not_installed("gbm")
@@ -104,8 +103,8 @@ test_that("no error in plot method for singleEventCB objects - hazard ratio with
                           var = "tgrade",
                           increment = 1,
                           xvar = "time",
-                          ci = T,
-                          rug = T))
+                          ci = TRUE,
+                          rug = TRUE))
 
     # check that supplying only one row to newdata works
     # and that the dataset is returned invisibly
@@ -115,8 +114,8 @@ test_that("no error in plot method for singleEventCB objects - hazard ratio with
                           var = "tgrade",
                           increment = 1,
                           xvar = "time",
-                          ci = F,
-                          rug = T, cex = 5))
+                          ci = FALSE,
+                          rug = TRUE, cex = 5))
 
     # check that supplying only one row to newdata works
     # and that the dataset is returned invisibly
@@ -127,8 +126,8 @@ test_that("no error in plot method for singleEventCB objects - hazard ratio with
                           var = "tgrade",
                           increment = 1,
                           xvar = "time",
-                          ci = F,
-                          rug = T, cex = 5, pch = 22)
+                          ci = FALSE,
+                          rug = TRUE, cex = 5, pch = 22)
     )
 
 
@@ -167,3 +166,30 @@ test_that("no error in plot method for singleEventCB objects - hazard ratio with
     expect_false(inherits(outglm_hr_noci, "try-error"))
     expect_false(inherits(outglm_hr_exposed, "try-error"))
 })
+
+library(data.table)
+mod_brcancer2 <- fitSmoothHazard(cens ~ ns(time, df = 3) * tgrade,
+                                 data = as.data.table(brcancer),
+                                 time = "time")
+
+test_that("make sure the data is returned by plot.singleEventCB", {
+    plot1 <- plot(mod_brcancer,
+                  type = "hr",
+                  newdata = brcancer[1, ],
+                  var = "tgrade",
+                  increment = 1,
+                  xvar = "time",
+                  ci = TRUE,
+                  rug = TRUE)
+    plot2 <- plot(mod_brcancer2,
+                  type = "hr",
+                  newdata = as.data.table(brcancer[1, ]),
+                  var = "tgrade",
+                  increment = 1,
+                  xvar = "time",
+                  ci = TRUE,
+                  rug = TRUE)
+
+    expect_true(inherits(plot1, "data.frame"))
+    expect_true(inherits(plot2, "data.frame"))
+})
